#
# spec file for package python-scitokens
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bname scitokens

Name:           python-scitokens
Version:        1.7.4
Release:        1.4
Summary:        SciToken reference implementation library
License:        Apache-2.0
URL:            https://scitokens.org
Source:         https://github.com/scitokens/scitokens/archive/refs/tags/v%{version}.tar.gz#/%{bname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Do not use pkg_resources gh#scitokens/scitokens#182
Patch0:         use-importlib-metadata.patch
BuildRequires:  %{python_module PyJWT >= 2.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT >= 2.2
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
SciTokens provide a token format for distributed authorization. The tokens are
self-describing, can be verified in a distributed fashion (no need to contact
the issuer to determine if the token is valid). This is convenient for a
federated environment where several otherwise-independent storage endpoints
want to delegate trust for an issuer for managing a storage allocation.

%prep
%autosetup -p1 -n scitokens-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/scitokens-admin-create-key
%python_clone -a %{buildroot}%{_bindir}/scitokens-admin-create-token
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative scitokens-admin-create-key
%python_install_alternative scitokens-admin-create-token

%postun
%python_uninstall_alternative scitokens-admin-create-key
%python_uninstall_alternative scitokens-admin-create-token

%files %{python_files}
%{python_sitelib}/scitokens*
%python_alternative %{_bindir}/scitokens-admin-create-key
%python_alternative %{_bindir}/scitokens-admin-create-token

%changelog
* Wed Apr 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.7.4:
  * Remove aud enforcement from deserialize function
  * Reduce length of comment line
  * Update minimum pyjwt
  * Remove use of six
- Drop patch python-scitokens-no-six.patch, included upstream
- Add patch use-importlib-metadata.patch:
  * Use importlib.metadata, rather than pkg_resources.
* Mon Nov 14 2022 pgajdos@suse.com
- added patches
  fix https://github.com/scitokens/scitokens/issues/169
  + python-scitokens-no-six.patch
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.7.2
  * Documentation changes release.
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.7.1
  * Add license to metadata by @duncanmmacleod in #150
  * Update badges in README by @duncanmmacleod in #152
  * Miscellaneous documentation fixes by @duncanmmacleod in #155
  * Update setup.py by @duncanmmacleod in #156
  * Adding codacy github action by @djw8605 in #158
  * Attempt to fix codacy in github actions by @djw8605 in #159
  * Add pyproject.toml file for PEP 517 builds by @lpsinger in #162
  * Install requires setuptools by @lpsinger in #163
* Thu Sep  1 2022 Steve Kowalik <steven.kowalik@suse.com>
- Do not use python_module for Requires.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.0:
  * Reference test files using relative paths
    [gh#citokens/scitokens#128].
  * Use shutil.move instead of os.rename
    [gh#citokens/scitokens#136].
  * Add error message for when SciToken.discover doesn't find a
    token [gh#citokens/scitokens#138].
  * SciToken.serialize: fix str/bytes mismatch
    [gh#citokens/scitokens#137].
  * Add rpmbuild github actions workflow
    [gh#citokens/scitokens#134].
  * Update the bogus url used in the tests
    [gh#citokens/scitokens#140].
  * Fix bug decoding a token with no audience
    [gh#citokens/scitokens#141].
  * Use unittest.mock to check UnableToCreateCache
    [gh#citokens/scitokens#139].
  * Add obsoletes for smoother Yum updates on EL7
    [gh#citokens/scitokens#127].
  * Update algorithm used to test UnsupportedKeyException
    [gh#citokens/scitokens#142].
  * Run test suite using pytest during rpmbuild
    [gh#citokens/scitokens#135].
  * Update pyjwt version in requirements.txt
    [gh#citokens/scitokens#131].
  * Typo fix in readme [gh#citokens/scitokens#144].
  * Default cached public keys set to 4 days
    [gh#citokens/scitokens#145].
* Fri Feb  4 2022 Christian Goll <cgoll@suse.com>
- initial commit of the python SciTokens interface
